@@ -1,5 +1,42 @@
-/* A. Belopolsky's Array interface */
+/* A. Belopolsky's Array interface, modified as seen fit 
+ * to accommodate changes in numpy and in Python 3. 
+ * This will be phased out
+ * as Numpy is now using memoryviews.
+ * Laurent Gautier - 2010
+ */
 
+/*
+ ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * Copyright (C) 2008-2011 Laurent Gautier
+ *
+ * Portions created by Alexander Belopolsky are 
+ * Copyright (C) 2006 Alexander Belopolsky.
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ *
+ * ***** END LICENSE BLOCK ***** */
 
 #include <Python.h>
 #include <Rdefines.h>
@@ -106,6 +143,8 @@ sexp_itemsize(SEXP sexp)
 /*     } */
 /* } */
 
+
+#if (PY_VERSION_HEX < 0x02070000)  
 static void
 array_struct_free(void *ptr, void *arr)
 {
@@ -114,7 +153,17 @@ array_struct_free(void *ptr, void *arr)
   Py_DECREF((PyObject *)arr);
   PyMem_Free(inter);
 }
-
+#else
+static void
+array_struct_free(PyObject *rpynumpycapsule)
+{
+  PyArrayInterface *inter = 
+    (PyArrayInterface *)(PyCapsule_GetPointer(rpynumpycapsule,
+					      NULL));
+  PyMem_Free(inter->shape);
+  PyMem_Free(inter);
+}
+#endif
 
 static PyObject* 
 array_struct_get(PySexpObject *self)
@@ -161,6 +210,12 @@ array_struct_get(PySexpObject *self)
     return NULL;
   }
   Py_INCREF(self);
+#if (PY_VERSION_HEX < 0x02070000) 
   return PyCObject_FromVoidPtrAndDesc(inter, self, array_struct_free);
+#else
+  return PyCapsule_New(inter,
+		       NULL, /* Numpy does not seem to give a name */
+		       (PyCapsule_Destructor) array_struct_free);
+#endif
 }
 
