@@ -14,36 +14,24 @@ import itertools
 import rpy2.rinterface as rinterface
 import rpy2.rlike.container as rlc
 
-import conversion
-
 from rpy2.robjects.robject import RObjectMixin, RObject
-from rpy2.robjects.methods import RS4
 from rpy2.robjects.vectors import *
 from rpy2.robjects.functions import Function, SignatureTranslatedFunction
+from rpy2.robjects.environments import Environment
+from rpy2.robjects.methods import RS4
 
-from rpy2.rinterface import NA_Real, NA_Integer, NA_Logical, NA_Character
+import conversion
+
+from rpy2.rinterface import Sexp, SexpVector, SexpClosure, SexpEnvironment, SexpS4, SexpExtPtr
+_globalenv = rinterface.globalenv
 
-_parse = rinterface.baseenv['parse']
-_reval = rinterface.baseenv['eval']
 # missing values
-# keep them in vectors to keep compatibility with the 2.1.x series 
-NA_real = FloatVector((NA_Real, ))
-NA_integer = IntVector((NA_Integer, ))
-NA_bool = BoolVector((NA_Logical, ))
-NA_character = StrVector((NA_Character, ))
-NA_complex = ComplexVector(_reval(_parse(text = rinterface.StrSexpVector(("NA_complex_", )))))
-
-# NULL
-NULL = _reval(_parse(text = rinterface.StrSexpVector(("NULL", ))))
-# TRUE/FALSE
-TRUE = _reval(_parse(text = rinterface.StrSexpVector(("TRUE", ))))
-FALSE = _reval(_parse(text = rinterface.StrSexpVector(("FALSE", ))))
-
+from rpy2.rinterface import NA_Real, NA_Integer, NA_Logical, NA_Character, NA_Complex, NULL
 
+_reval = rinterface.baseenv['eval']
 
 #FIXME: close everything when leaving (check RPy for that).
 
-
 def default_ri2py(o):
     """ Convert :class:`rpy2.rinterface.Sexp` to higher-level objects,
     without copying the R objects.
@@ -54,14 +42,14 @@ def default_ri2py(o):
 
     res = None
     try:
-        rcls = o.do_slot("class")[0]
+        rcls = o.do_slot("class")
     except LookupError, le:
-        rcls = None
+        rcls = [None]
 
     if isinstance(o, RObject):
         res = o
-    elif isinstance(o, rinterface.SexpVector):
-        if rcls == 'data.frame':
+    elif isinstance(o, SexpVector):
+        if 'data.frame' in rcls:
             res = vectors.DataFrame(o)
         if res is None:
             try:
@@ -72,7 +60,7 @@ def default_ri2py(o):
                     res = vectors.Array(o)
             except LookupError, le:
                 if o.typeof == rinterface.INTSXP:
-                    if rcls == 'factor':
+                    if 'factor' in rcls:
                         res = vectors.FactorVector(o)
                     else:
                         res = vectors.IntVector(o)
@@ -80,17 +68,23 @@ def default_ri2py(o):
                     res = vectors.FloatVector(o)
                 elif o.typeof == rinterface.STRSXP:
                     res = vectors.StrVector(o)
-                elif o.typeof == rinterface.LANGSXP and rcls == 'formula':
+                elif o.typeof == rinterface.VECSXP:
+                    res = vectors.ListVector(o)
+                elif o.typeof == rinterface.LANGSXP and 'formula' in rcls:
                     res = Formula(o)
                 else:
                     res = vectors.Vector(o)
 
-    elif isinstance(o, rinterface.SexpClosure):
+    elif isinstance(o, SexpClosure):
         res = SignatureTranslatedFunction(o)
-    elif isinstance(o, rinterface.SexpEnvironment):
+    elif isinstance(o, SexpEnvironment):
         res = Environment(o)
-    elif isinstance(o, rinterface.SexpS4):
+    elif isinstance(o, SexpS4):
         res = RS4(o)
+    elif isinstance(o, SexpExtPtr):
+        res = o
+    elif o is NULL:
+        res = o
     else:
         res = RObject(o)
     return res
@@ -109,7 +103,7 @@ def default_py2ri(o):
     """
     if isinstance(o, RObject):
         res = rinterface.Sexp(o)
-    if isinstance(o, rinterface.Sexp):
+    if isinstance(o, Sexp):
         res = o
     elif isinstance(o, array.array):
         if o.typecode in ('h', 'H', 'i', 'I'):
@@ -121,7 +115,11 @@ def default_py2ri(o):
     elif isinstance(o, bool):
         res = rinterface.SexpVector([o, ], rinterface.LGLSXP)
     elif isinstance(o, int) or isinstance(o, long):
-        res = rinterface.SexpVector([o, ], rinterface.INTSXP)
+        # special case for NA_Logical
+        if o is rinterface.NA_Logical:
+            res = rinterface.SexpVector([o, ], rinterface.LGLSXP)
+        else:
+            res = rinterface.SexpVector([o, ], rinterface.INTSXP)
     elif isinstance(o, float):
         res = rinterface.SexpVector([o, ], rinterface.REALSXP)
     elif isinstance(o, str):
@@ -151,41 +149,9 @@ conversion.py2ro = default_py2ro
 
 
 
-
-class Environment(RObjectMixin, rinterface.SexpEnvironment):
-    """ An R environement. """
-    
-    def __init__(self, o=None):
-        if o is None:
-            o = rinterface.baseenv["new.env"](hash=rinterface.SexpVector([True, ], rinterface.LGLSXP))
-        super(Environment, self).__init__(o)
-
-    def __getitem__(self, item):
-        res = super(Environment, self).__getitem__(item)
-        res = conversion.ri2py(res)
-        res.__rname__ = item
-        return res
-
-    def __setitem__(self, item, value):
-        robj = conversion.py2ro(value)
-        super(Environment, self).__setitem__(item, robj)
-
-    def get(self, item, wantfun = False):
-        """ Get a object from its R name/symol
-        :param item: string (name/symbol)
-        :rtype: object (as returned by :func:`conversion.ri2py`)
-        """
-        res = super(Environment, self).get(item, wantfun = wantfun)
-        res = conversion.ri2py(res)
-        res.__rname__ = item
-        return res
-
-
-
-
 class Formula(RObjectMixin, rinterface.Sexp):
 
-    def __init__(self, formula, environment = rinterface.globalenv):
+    def __init__(self, formula, environment = _globalenv):
         if isinstance(formula, str):
             inpackage = rinterface.baseenv["::"]
             asformula = inpackage(rinterface.StrSexpVector(['stats', ]), 
@@ -236,7 +202,7 @@ class R(object):
             raise orig_ae
 
     def __getitem__(self, item):
-        res = rinterface.globalenv.get(item)
+        res = _globalenv.get(item)
         res = conversion.ri2py(res)
         res.__rname__ = item
         return res
@@ -255,12 +221,12 @@ class R(object):
         return s
 
     def __call__(self, string):
-        p = self.parse(text=string)
+        p = rinterface.parse(string)
         res = self.eval(p)
         return res
 
 r = R()
 
-globalenv = conversion.ri2py(rinterface.globalenv)
+globalenv = conversion.ri2py(_globalenv)
 baseenv = conversion.ri2py(rinterface.baseenv)
 emptyenv = conversion.ri2py(rinterface.emptyenv)
