@@ -1,23 +1,34 @@
+from types import ModuleType
 import rpy2.rinterface as rinterface
 import rpy2.robjects.lib
-import rpy2.robjects.conversion as conversion
+import conversion as conversion
 from rpy2.robjects.functions import SignatureTranslatedFunction
-from rpy2.robjects import NULL
+from rpy2.robjects.constants import NULL
 
 _require = rinterface.baseenv['require']
 _as_env = rinterface.baseenv['as.environment']
+_find_package = rinterface.baseenv['.find.package']
+_packages = rinterface.baseenv['.packages']
+_libpaths = rinterface.baseenv['.libPaths']
+_loaded_namespaces = rinterface.baseenv['loadedNamespaces']
 
 def quiet_require(name, lib_loc = None):
-    _parse = rinterface.baseenv['parse']
+    """ Load an R package /quietly/ (suppressing messages to the console). """
     if lib_loc == None:
         lib_loc = "NULL"
     expr_txt = "suppressPackageStartupMessages(base::require(%s, lib.loc=%s))" \
         %(name, lib_loc)
-    expr = _parse(text = rinterface.StrSexpVector([expr_txt, ]))
+    expr = rinterface.parse(expr_txt)
     ok = rinterface.baseenv['eval'](expr)
     return ok
 
-class Package(object):
+def get_packagepath(package):
+    """ return the path to an R package installed """
+    res = _find_package(rinterface.StrSexpVector((package, )))
+    return res[0]
+
+
+class Package(ModuleType):
     """ Models an R package
     (and can do so from an arbitrary environment - with the caution
     that locked environments should mostly be considered).
@@ -26,6 +37,7 @@ class Package(object):
     def __init__(self, env, name, translation = {}):
         """ Create a Python module-like object from an R environment,
         using the specified translation if defined. """
+        super(Package, self).__init__(name)
         self._env = env
         self.__rname__ = name
         self._translation = translation
@@ -52,11 +64,12 @@ class Package(object):
                 if dot_i > -1:
                     rpyname = rname.replace('.', '_')
                     if rpyname in self._rpy2r:
-                        raise LibraryError(('Conflict in converting R symbol'+\
-                                            ' to a Python symbol ' +\
-                                            '(%s -> %s while there is already'+\
-                                            ' %s)') %(rname, rpyname,
-                                                      rpyname))
+                        msg = ('Conflict when converting R symbol'+\
+                                   ' to a Python symbol ' +\
+                                   '(%s -> %s while there is already'+\
+                                   ' %s)') %(rname, rpyname,
+                                             rpyname)
+                        raise LibraryError(msg)
                 else:
                     rpyname = rname
                 if rpyname in self.__dict__ or rpyname == '__dict__':
@@ -66,11 +79,15 @@ class Package(object):
                                        'a Python object attribute')
             self._rpy2r[rpyname] = rname
             rpyobj = conversion.ri2py(self._env[rname])
-            rpyobj.__rname__ = rname
+            if hasattr(rpyobj, '__rname__'):
+                rpyobj.__rname__ = rname
             #FIXME: shouldn't the original R name be also in the __dict__ ?
             self.__dict__[rpyname] = rpyobj
 
 
+    def __repr__(self):
+        s = super(Package, self).__repr__()
+        return 'rpy2.robjecs.packages.Package as a ' + s
 
 class SignatureTranslatedPackage(Package):
     def __fill_rpy2r__(self):
@@ -125,3 +142,4 @@ def wherefrom(symbol, startenv = rinterface.globalenv):
             else:
                 tryagain = True
     return conversion.ri2py(env)
+
